#pragma once

// Проверяет, является ли инструкция JMP
bool IsJumpInstruction(const unsigned char* data, size_t size) {
    if (!data || size < 1)
        return false;

    // JMP rel32 (E9 cd)
    if (size >= 5 && data[0] == 0xE9)
        return true;

    // JMP rel8 (EB cb)
    if (size >= 2 && data[0] == 0xEB)
        return true;

    // JMP r/m32 (FF /4)
    if (size >= 2 && data[0] == 0xFF && (data[1] & 0x38) == 0x20)
        return true;

    return false;
}

// Проверяет, является ли инструкция CALL
bool IsCallInstruction(const unsigned char* data, size_t size) {
    if (!data || size < 1)
        return false;

    // CALL rel32 (E8 cd)
    if (size >= 5 && data[0] == 0xE8)
        return true;

    // CALL r/m32 (FF /2)
    if (size >= 2 && data[0] == 0xFF && (data[1] & 0x38) == 0x10)
        return true;

    // CALL m32 (FF /3)
    if (size >= 2 && data[0] == 0xFF && (data[1] & 0x38) == 0x18)
        return true;

    return false;
}

// Проверяет, является ли инструкция RET
bool IsRetInstruction(const unsigned char* data, size_t size) {
    if (!data || size < 1)
        return false;

    // RET (C3)
    if (size >= 1 && data[0] == 0xC3)
        return true;

    // RET imm16 (C2 iw)
    if (size >= 3 && data[0] == 0xC2)
        return true;

    // RET far (CB)
    if (size >= 1 && data[0] == 0xCB)
        return true;

    // RET far imm16 (CA iw)
    if (size >= 3 && data[0] == 0xCA)
        return true;

    return false;
}
